@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -94,6 +94,8 @@ G_DEFINE_TYPE (EvApplication, ev_application, G_TYPE_OBJECT);
 #define APPLICATION_DBUS_INTERFACE   "org.gnome.evince.Application"
 #endif
 
+static const gchar *userdir = NULL;
+
 /**
  * ev_application_get_instance:
  *
@@ -610,6 +612,10 @@ ev_application_open_uri_in_window (EvApplication  *application,
 				   const gchar    *search_string,
 				   guint           timestamp)
 {
+#ifdef GDK_WINDOWING_X11
+	GdkWindow *gdk_window;
+#endif
+
 	if (screen) {
 		ev_stock_icons_set_screen (screen);
 		gtk_window_set_screen (GTK_WINDOW (ev_window), screen);
@@ -619,13 +625,15 @@ ev_application_open_uri_in_window (EvApplication  *application,
 	   we can restore window size without flickering */
 	ev_window_open_uri (ev_window, uri, dest, mode, search_string);
 
-	if (!GTK_WIDGET_REALIZED (GTK_WIDGET (ev_window)))
+	if (!gtk_widget_get_realized (GTK_WIDGET (ev_window)))
 		gtk_widget_realize (GTK_WIDGET (ev_window));
 
 #ifdef GDK_WINDOWING_X11
+	gdk_window = gtk_widget_get_window (GTK_WIDGET (ev_window));
+
 	if (timestamp <= 0)
-		timestamp = gdk_x11_get_server_time (GTK_WIDGET (ev_window)->window);
-	gdk_x11_window_set_user_time (GTK_WIDGET (ev_window)->window, timestamp);
+		timestamp = gdk_x11_get_server_time (gdk_window);
+	gdk_x11_window_set_user_time (gdk_window, timestamp);
 
 	ev_document_fc_mutex_lock ();
 	gtk_window_present (GTK_WINDOW (ev_window));
@@ -703,19 +711,24 @@ ev_application_open_window (EvApplication *application,
 			    guint32        timestamp)
 {
 	GtkWidget *new_window = ev_window_new ();
+#ifdef GDK_WINDOWING_X11
+	GdkWindow *gdk_window;
+#endif
 
 	if (screen) {
 		ev_stock_icons_set_screen (screen);
 		gtk_window_set_screen (GTK_WINDOW (new_window), screen);
 	}
 
-	if (!GTK_WIDGET_REALIZED (new_window))
+	if (!gtk_widget_get_realized (new_window))
 		gtk_widget_realize (new_window);
 
 #ifdef GDK_WINDOWING_X11
+	gdk_window = gtk_widget_get_window (GTK_WIDGET (new_window));
+
 	if (timestamp <= 0)
-		timestamp = gdk_x11_get_server_time (new_window->window);
-	gdk_x11_window_set_user_time (new_window->window, timestamp);
+		timestamp = gdk_x11_get_server_time (gdk_window);
+	gdk_x11_window_set_user_time (gdk_window, timestamp);
 
 	gtk_window_present (GTK_WINDOW (new_window));
 #else
@@ -802,9 +815,14 @@ ev_application_accel_map_save (EvApplication *application)
 	gchar *tmp_filename;
 	gint   fd;
 
-	accel_map_file = g_build_filename (g_get_home_dir (),
-					   ".gnome2", "accels",
-					   "evince", NULL);
+	if (userdir) {
+		accel_map_file = g_build_filename (userdir, "accels",
+						   "evince", NULL);
+	} else {
+		accel_map_file = g_build_filename (g_get_home_dir (),
+						   ".gnome2", "accels",
+						   "evince", NULL);
+	}
 
 	tmp_filename = g_strdup_printf ("%s.XXXXXX", accel_map_file);
 
@@ -832,9 +850,15 @@ ev_application_accel_map_load (EvApplication *application)
 {
 	gchar *accel_map_file;
 
-	accel_map_file = g_build_filename (g_get_home_dir (),
-					   ".gnome2", "accels",
-					   "evince", NULL);
+	if (userdir) {
+		accel_map_file = g_build_filename (userdir, "accels",
+						   "evince", NULL);
+	} else {
+		accel_map_file = g_build_filename (g_get_home_dir (),
+						   ".gnome2", "accels",
+						   "evince", NULL);
+	}
+
 	gtk_accel_map_load (accel_map_file);
 	g_free (accel_map_file);
 }
@@ -853,6 +877,9 @@ ev_application_shutdown (EvApplication *application)
 
 	ev_application_accel_map_save (application);
 
+	g_object_unref (application->scr_saver);
+	application->scr_saver = NULL;
+
 #ifdef ENABLE_DBUS
 	if (application->keys) {
 		g_object_unref (application->keys);
@@ -889,10 +916,14 @@ ev_application_init (EvApplication *ev_application)
 {
 	GError *error = NULL;
 
-        ev_application->dot_dir = g_build_filename (g_get_home_dir (),
-                                                    ".gnome2",
-                                                    "evince",
-                                                    NULL);
+	userdir = g_getenv ("GNOME22_USER_DIR");
+	if (userdir)
+		ev_application->dot_dir = g_build_filename (userdir, "evince", NULL);
+	else
+		ev_application->dot_dir = g_build_filename (g_get_home_dir (),
+							    ".gnome2",
+							    "evince",
+							    NULL);
 
 #ifdef G_OS_WIN32
 {
@@ -910,13 +941,14 @@ ev_application_init (EvApplication *ev_application)
 
 	ev_application_accel_map_load (ev_application);
 
+	ev_application->scr_saver = totem_scrsaver_new ();
+
 #ifdef ENABLE_DBUS
 	ev_application->connection = dbus_g_bus_get (DBUS_BUS_STARTER, &error);
 	if (ev_application->connection) {
 		dbus_g_connection_register_g_object (ev_application->connection,
 						     APPLICATION_DBUS_OBJECT_PATH,
 						     G_OBJECT (ev_application));
-		ev_application->scr_saver = totem_scrsaver_new (ev_application->connection);
 	} else {
 		g_warning ("Error connection to DBus: %s\n", error->message);
 		g_error_free (error);
@@ -992,15 +1024,13 @@ ev_application_get_filechooser_uri (EvApplication       *application,
 void
 ev_application_screensaver_enable (EvApplication *application)
 {
-	if (application->scr_saver)
-		totem_scrsaver_enable (application->scr_saver);	
+	totem_scrsaver_enable (application->scr_saver);
 }
 
 void
 ev_application_screensaver_disable (EvApplication *application)
 {
-	if (application->scr_saver)
-		totem_scrsaver_disable (application->scr_saver);	
+	totem_scrsaver_disable (application->scr_saver);
 }
 
 const gchar *
