@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -54,6 +54,7 @@
 
 static gchar   *ev_page_label;
 static gchar   *ev_find_string;
+static gint     ev_page_index = 0;
 static gboolean preview_mode = FALSE;
 static gboolean fullscreen_mode = FALSE;
 static gboolean presentation_mode = FALSE;
@@ -61,6 +62,7 @@ static gboolean unlink_temp_file = FALSE;
 static gchar   *print_settings;
 static const char **file_arguments = NULL;
 
+
 static gboolean
 option_version_cb (const gchar *option_name,
                    const gchar *value,
@@ -75,7 +77,8 @@ option_version_cb (const gchar *option_name,
 
 static const GOptionEntry goption_options[] =
 {
-	{ "page-label", 'p', 0, G_OPTION_ARG_STRING, &ev_page_label, N_("The page of the document to display."), N_("PAGE")},
+	{ "page-label", 'p', 0, G_OPTION_ARG_STRING, &ev_page_label, N_("The page label of the document to display."), N_("PAGE")},
+	{ "page-index", 'i', 0, G_OPTION_ARG_INT, &ev_page_index, N_("The page number of the document to display."), N_("NUMBER")},
 	{ "fullscreen", 'f', 0, G_OPTION_ARG_NONE, &fullscreen_mode, N_("Run evince in fullscreen mode"), NULL },
 	{ "presentation", 's', 0, G_OPTION_ARG_NONE, &presentation_mode, N_("Run evince in presentation mode"), NULL },
 	{ "preview", 'w', 0, G_OPTION_ARG_NONE, &preview_mode, N_("Run evince as a previewer"), NULL },
@@ -83,7 +86,7 @@ static const GOptionEntry goption_options[] =
 	{ "unlink-tempfile", 'u', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &unlink_temp_file, NULL, NULL },
 	{ "print-settings", 't', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &print_settings, NULL, NULL },
 	{ "version", 0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL },
-	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &file_arguments, NULL, N_("[FILE...]") },
+	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &file_arguments, NULL, N_("[FILE…]") },
 	{ NULL }
 };
 
@@ -159,6 +162,8 @@ load_files (const char **files)
 
 	if (ev_page_label)
 		global_dest = ev_link_dest_new_page_label (ev_page_label);
+	else if (ev_page_index)
+		global_dest = ev_link_dest_new_page (MAX (0, ev_page_index - 1));
 
 	if (fullscreen_mode)
 		mode = EV_WINDOW_MODE_FULLSCREEN;
@@ -166,13 +171,24 @@ load_files (const char **files)
 		mode = EV_WINDOW_MODE_PRESENTATION;
 
 	for (i = 0; files[i]; i++) {
+		const gchar *filename;
 		gchar       *uri;
 		gchar       *label;
 		GFile       *file;
 		EvLinkDest  *dest = NULL;
 		const gchar *app_uri;
 
-		file = g_file_new_for_commandline_arg (files[i]);
+		filename = files[i];
+		label = strchr (filename, '#');
+		if (label) {
+			*label = 0;
+			label++;
+			dest = ev_link_dest_new_page_label (label);
+		} else if (global_dest) {
+			dest = g_object_ref (global_dest);
+		}
+
+		file = g_file_new_for_commandline_arg (filename);
 		uri = g_file_get_uri (file);
 		g_object_unref (file);
 
@@ -182,14 +198,7 @@ load_files (const char **files)
 			continue;
 		}
 
-		label = strchr (uri, '#');
-		if (label) {
-			*label = 0;
-			label++;
-			dest = ev_link_dest_new_page_label (label);
-		} else if (global_dest) {
-			dest = g_object_ref (global_dest);
-		}
+
 
 		ev_application_open_uri_at_dest (EV_APP, uri, screen, dest,
 						 mode, ev_find_string,
@@ -207,6 +216,11 @@ main (int argc, char *argv[])
 	GOptionContext *context;
 	GError         *error = NULL;
 
+#ifdef WITH_GCONF
+	/* Remove when porting is done */
+	g_setenv ("GSETTINGS_BACKEND", "gconf", FALSE);
+#endif
+
 #ifdef G_OS_WIN32
 
     if (fileno (stdout) != -1 &&
